<?php defined( 'ABSPATH' ) || exit;

/**
 * WebinarIgnition setup
 *
 * @package WebinarIgnition
 * @since   1.9.187
 */

/**
 * Main WebinarIgnition Class.
 *
 * @class WebinarIgnition
 */
final class WebinarIgnition {

	/**
	 * WebinarIgnition version.
	 *
	 * @var string
	 */
	public $version = '2.5.3';

	/**
	 * WebinarIgnition version.
	 *
	 * @var string
	 */
	public static $plugin_basename = null;

	/**
	 * The single instance of the class.
	 *
	 * @var WebinarIgnition
	 */
	protected static $_instance = null;

	/**
	 * Main WebinarIgnition Instance.
	 *
	 * Ensures only one instance of WebinarIgnition is loaded or can be loaded.
	 *
	 * @return WebinarIgnition - Main instance.
	 */
	public static function instance() {
		if ( is_null( self::$_instance ) ) {
			self::$_instance = new self();
		}
		return self::$_instance;
	}

	/**
	 * WebinarIgnition Constructor.
	 */
	public function __construct() {
		self::$plugin_basename = self::get_plugin_basename();
		$this->includes();
		$this->init_hooks();
	}

	/**
	 * Hook into actions and filters.
	 *
	 */
	private function init_hooks() {
	    add_action('webinarignition_activate', 'webinarignition_installer');
		add_action('admin_init', array($this, 'webinarignition_redirect_after_installation'));

		add_action( 'plugins_loaded', array($this, 'webinarignition_load_plugin_textdomain'));

		add_action('init', array($this, 'init'));
		add_action('admin_head', array($this, 'admin_head'));
		add_action('init', array($this, 'sign_in_support_staff'));
		add_action('webinarignition_lead_created', array($this, 'lead_created'), 30, 2);

		add_filter('sac_logged_username', array('WebinarignitionIntegration', 'set_sac_logged_username'), 999, 2);

		// add_filter( 'pre_set_site_transient_update_plugins', array( $this, 'check_plugins_updates' ) );
		//add_filter( 'auto_update_plugin', [$this, 'auto_update_plugin'], 10, 2 );

		add_action( "in_plugin_update_message-" . self::$plugin_basename, array( $this, 'add_update_notice' ), 10, 2 );
		add_filter( 'site_transient_update_plugins', array( $this, 'restrict_plugin_update' ) );
	}

	public function restrict_plugin_update( $value ) {

		global $pagenow;

		if( 'update-core.php' !== $pagenow ) {
			return $value;
		}

		$statusCheck = WebinarignitionLicense::get_license_level();

		if( !in_array( $statusCheck->switch, array('basic', 'pro', 'free') ) ) {
			return $value;
		}

		if ( isset( $value->response[self::$plugin_basename] ) ) {
			if( !self::is_plugin_update_available($value->response[self::$plugin_basename]) ) {
				return $value;
			} else {
				unset( $value->response[self::$plugin_basename] );
            }
		}

		return $value;
	}

	public static function is_plugin_update_available($plugin_update = false) {
	    if( !$plugin_update ) {
		    $available_plugin_updates = get_site_transient( 'update_plugins' );
		    if ( isset( $available_plugin_updates->response[ self::$plugin_basename ] ) ) {
			    $plugin_update = $available_plugin_updates->response[ self::$plugin_basename ];
		    }
	    }

		$current_version = WEBINARIGNITION_VERSION;
		$old_version = '2.16.0';
		$new_version = '3.00.0';

		//Check if, current version is greater than or equals to 2.16.0 and less than 3.00.0, and new version is greater than or equals to 3.00.0
		$update_available = version_compare($current_version, $old_version, '>=') && version_compare( $current_version, $new_version, '<') && ($plugin_update && version_compare($plugin_update->new_version, $new_version, '>=') );

		return $update_available;
	}

	public function admin_head() {
		if( get_current_screen()->id != 'plugins' && get_current_screen()->id != 'update-core' ) return;

		if( !self::is_plugin_update_available() ) return;

		?>
        <script>
            (function( $ ) {
                $(document).ready(function() {
                    if($('input[type=checkbox][value="<?php echo self::$plugin_basename; ?>"]').length) {
                        $('input[type=checkbox][value="<?php echo self::$plugin_basename; ?>"]').remove();
                    }
                });
            })( jQuery );
        </script>
		<?php
	}

	public function auto_update_plugin($update, $item) {
		$statusCheck = WebinarignitionLicense::get_license_level();
		$is_basic_pro = in_array($statusCheck->switch, ['pro','basic']);

		if( $is_basic_pro && $item->slug === 'webinar-ignition' ) { //Disable auto update for basic/pro licenses
			Webinar_Ignition_Helper::debug_log( $update, false, true );
			Webinar_Ignition_Helper::debug_log( $item, false );

			$update = false;
		}

		return $update;
	}

	public static function get_plugin_basename() {
		return plugin_basename(WEBINARIGNITION_PLUGIN_FILE);
	}

	public function add_update_notice(){

		$statusCheck = WebinarignitionLicense::get_license_level();

		if( !in_array($statusCheck->switch, ['free','basic','pro']) ) {
			return;
		}

		if( !self::is_plugin_update_available() ) {
			return;
		}
		?>
        <hr>
        <span>
                <span class="dashicons dashicons-warning" style="color:#dba62b"></span>
                <?php if( in_array($statusCheck->switch, ['free','basic','pro']) ) {
	                $license_type = !empty($statusCheck->title) ? $statusCheck->title : __( 'Free', 'webinarignition' );
	                $license_count = "5-500";
	                if( $statusCheck->switch == 'basic' ) {
		                $license_count = 100;
	                } else if( $statusCheck->switch == 'pro' ) {
		                $license_count = 200;
	                }

	                $message = __('After UPGRADE you will get all ULTIMATE features like <strong>live webinars</strong>, new design, webhooks, webinar grid, multi language webinars, shortcodes, and future plugin updates for FREE. However the number of webinar registrations will be restricted to %s per month');

	                if( $statusCheck->switch == 'free' ) {
		                $message .= __(' and webinar watch time is limited to 45 minutes');
	                }
	                $message .= '.';
	                ?>
                    <strong><?php echo sprintf(esc_html('Important update for %s license holders!', 'webinarignition'), $license_type); ?></strong>
                    <div style="padding:10px;">
                        <?php echo sprintf($message, $license_count); ?>
                    </div>
                    <?php if( $statusCheck->switch == 'free' ): ?>
                        <div style="padding:10px;"><?php echo sprintf(__('PS: At the moment you got minimal features (old design, only one shortcode, …) in live webinars (unlimited registrations) and evergreen (with all features) with up to 50 registrations for free per months. Get the most webinar success by UPGRADE now.'), $license_count); ?></div>
	                <?php endif; ?>
                <?php } ?>
            </span>
        <script>
            jQuery(document).ready(function($){
                $('.update-message').find('p').each( function(){
                    if( $(this).text().length < 1 ){
                        $(this).remove();
                    }
                });
            });
        </script>
		<?php
	}


	public function webinarignition_load_plugin_textdomain(   ) {

		add_filter( 'plugin_locale', array($this, 'webinarignition_check_de_locale'));
		load_plugin_textdomain( 'webinarignition', false,  plugin_basename( dirname( WEBINARIGNITION_PLUGIN_FILE )  . '/languages'  ) );

	}

	public function webinarignition_check_de_locale( $domain  ) {

		$site_lang      = get_user_locale();
		$de_lang_list   = array(
			'de_CH_informal',
			'de_DE_formal',
			'de_AT',
			'de_CH',
			'de_DE'
		);

		if (in_array($site_lang, $de_lang_list)) {
			return 'de_DE';
		}
		return $domain;

	}

	public function webinarignition_redirect_after_installation(   ) {

		if ( is_user_logged_in() && intval( get_option( 'wi_redirect_after_installation' ) ) === wp_get_current_user()->ID ):

			delete_option( 'wi_redirect_after_installation' );
			add_option( 'wi_first_install', wp_get_current_user()->ID );
			wp_safe_redirect( get_admin_url() . 'admin.php?page=webinarignition-dashboard' );
			exit;

		endif;

	}

	public function sign_in_support_staff( ){
		if (!isset($_GET['console']) || (empty($_GET['_wi_host_token']) && empty($_GET['_wi_support_token']))) {
			return;
		}

		$postID = url_to_postid( $_SERVER['REQUEST_URI'] );
		if ( empty( $postID ) ) return;

		$webinar_id = absint( get_post_meta( $postID, 'webinarignitionx_meta_box_select', true ) ); //Check if webinar page
		if ( empty( $webinar_id ) ) {
			return;
		}
		$webinar_data = get_option( 'webinarignition_campaign_' . $webinar_id );
		if ( empty( $webinar_data ) ){
			return;
		}

		if ( ! empty( $_GET['_wi_support_token'] ) ) {
			if (!WebinarignitionManager::is_support_enabled($webinar_data) || empty( $webinar_data->support_staff_count )){
				return;
			}
			$wtlwp_token    = sanitize_key( $_GET['_wi_support_token'] );  // Input var okay.
			$user_query     = new WP_User_Query( array( 'meta_key' => '_wi_support_token', 'meta_value' => $wtlwp_token ) );
		}

		if ( ! empty( $_GET['_wi_host_token'] ) ) {
			if (!WebinarignitionManager::is_support_enabled($webinar_data, 'host') || empty( $webinar_data->host_member_count )) {
				return;
			}
			$wtlwp_token    = sanitize_key( $_GET['_wi_host_token'] );  // Input var okay.
			$user_query     = new WP_User_Query( array( 'meta_key' => '_wi_host_token', 'meta_value' => $wtlwp_token ) );
		}

		if (empty($user_query)) {
			return;
		}

		$users          = $user_query->get_results();
		if (empty($users)) {
			return;
		}
		$support_member = $users[0];
		$do_login = true;

		$support_member_user_id = $support_member->ID;
		if ( is_user_logged_in() ) {
			$current_user_id = get_current_user_id();

			if ( $support_member_user_id !== $current_user_id ) wp_logout();
			else $do_login = false;
		}

		if ( $do_login ) {
			$support_member_login = $support_member->login;
			wp_set_current_user( $support_member_user_id, $support_member_login );
			wp_set_auth_cookie( $support_member_user_id );

			do_action( 'webinarignition_support_login', $support_member );
		}

		$support_link = $webinar_data->webinar_permalink . '?console' ;

		wp_redirect($support_link);
		exit;
	}


	/**
	 * @param $id
	 * @param $table
	 * TODO - Move it to another place later
	 */
	public function lead_created($id, $table) {
		// Increment limit counter only for evergreen webinar
		global $wpdb;

		if ($table !== $wpdb->prefix.'webinarignition_leads') {
			WebinarignitionLicense::increment_free_limit_counter();
		}
	}


	/**
	 * What type of request is this?
	 *
	 * @param  string $type admin, ajax, cron or frontend.
	 * @return bool
	 */
	private function is_request( $type ) {
		switch ( $type ) {
			case 'admin':
				return is_admin();
			case 'ajax':
				return defined( 'DOING_AJAX' );
			case 'cron':
				return defined( 'DOING_CRON' );
			case 'frontend':
				return ( ! is_admin() ) && ! defined( 'DOING_CRON' );
		}
	}

	/**
	 * Include required core files used in admin and on the frontend.
	 */
	public function includes() {

		include_once WEBINARIGNITION_PATH . 'vendor/autoload.php';
		include_once WEBINARIGNITION_PATH . 'inc/class-webinar-ignition-helper.php';
		include_once WEBINARIGNITION_PATH . 'inc/wi-formatting-functions.php';
		include_once WEBINARIGNITION_PATH . "inc/WebinarIgnition_Logs.php";
		include_once WEBINARIGNITION_PATH . 'inc/wi-admin-functions.php';

		// license
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionManager.php';
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionEmailManager.php';

		// migrations
		include_once WEBINARIGNITION_PATH . 'inc/migrations.php';


		// leads
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionLeadsManager.php';

		// license
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionLicense.php';

		// updates
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionUpdates.php';

		// Ajax
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionAjax.php';

		// Ajax
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionQA.php';

		// Ajax
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionPowerups.php';
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionPowerupsShortcodes.php';

		// Third party plugins integration
		include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionIntegration.php';

		// Functions
		include_once WEBINARIGNITION_PATH . 'inc/Functions/DateTimeFunctions.php';
		include_once WEBINARIGNITION_PATH . 'inc/Functions/WebinarFunctions.php';
		include_once WEBINARIGNITION_PATH . 'inc/Functions/LeadFunctions.php';

		include_once WEBINARIGNITION_PATH . "inc/Helpers/DateHelpers.php";
		include_once WEBINARIGNITION_PATH . "inc/Functions/extra_functions.php";

		// AJAX Callbacks:
		include_once WEBINARIGNITION_PATH . "inc/callback.php";
		include_once WEBINARIGNITION_PATH . "inc/callback2.php";
		include_once WEBINARIGNITION_PATH . "inc/callback3.php";

		// Email service integration
		include_once WEBINARIGNITION_PATH . "inc/email_service_integration.php";
		include_once WEBINARIGNITION_PATH . "inc/autowebinar_get_dates.php";

		// Image Uploader:
		include_once WEBINARIGNITION_PATH . "inc/image.php";

		//Webhooks
		if( ( !defined('WEBINAR_IGNITION_DISABLE_WEBHOOKS') || WEBINAR_IGNITION_DISABLE_WEBHOOKS === false ) && WebinarignitionPowerups::is_ultimate() ) {
			include_once WEBINARIGNITION_PATH . 'admin/class-webinarignition-admin-webhooks-list-table.php';
			include_once WEBINARIGNITION_PATH . 'inc/class.WebinarignitionWebhooks.php';
		}

		// Menu Here:
		include_once WEBINARIGNITION_PATH . "inc/menu.php";

		// Dashboard:
		include_once WEBINARIGNITION_PATH . "UI/index.php";

		// Page Link:
		include_once WEBINARIGNITION_PATH . "inc/page_link.php";

		// NEW :: Shortcode Widget
		include_once WEBINARIGNITION_PATH . "inc/shortcode_widget.php";
		include_once WEBINARIGNITION_PATH . 'inc/wi-frontend-templates-functions.php';

		if ( $this->is_request( 'frontend' ) ) {
			$this->frontend_includes();
		}

		include_once WEBINARIGNITION_PATH . "inc/class-wi-emails.php";

	}

	/**
	 * Include required frontend files.
	 */
	public function frontend_includes() {
		include_once WEBINARIGNITION_PATH . 'inc/wi-frontend-functions.php';
	}

	/**
	 * Function used to Init WebinarIgnition Template Functions - This makes them pluggable by plugins and themes.
	 */
	public function include_template_functions() {
//		include_once WEBINARIGNITION_PATH . 'inc/wi-template-functions.php';
	}

	/**
	 * Init WebinarIgnition when WordPress Initialises.
	 */
	public function init() {
		WebinarignitionUpdates::check_updates();
		WebinarignitionLicense::free_limitation();
//		// Init action.
//		do_action( 'webinarignition_init' );
	}

	/**
	 * Get the template path.
	 *
	 * @return string
	 */
	public function template_path() {
		return apply_filters( 'webinarignition_template_path', 'webinarignition/' );
	}

	/**
	 * Get Ajax URL.
	 *
	 * @return string
	 */
	public function ajax_url() {
		return admin_url( 'admin-ajax.php', 'relative' );
	}
}