<?php


class WebinarignitionManager {
    public static function is_webinarignition() {
        $input_get = filter_input_array( INPUT_GET );

        global $post;

        if (empty($post)) return false;

        if (!empty($input_get["webinar"])) { // Maybe shortcode page
            $webinar_id = urlencode( $input_get["webinar"] );
            $is_webinar_id_protected = WebinarignitionManager::is_webinar_id_protected($webinar_id);

            if (!empty($is_webinar_id_protected)) $webinar_id = $is_webinar_id_protected;
            $webinar_data = WebinarignitionManager::get_webinar_data($webinar_id);

            if (
                !empty($webinar_data)
                && WebinarignitionPowerupsShortcodes::is_enabled($webinar_data)
            ) {
                return $webinar_data;
            }
        } else { // Maybe wi page
	        $webinar_id = absint( get_post_meta( $post->ID, 'webinarignitionx_meta_box_select', true ) ); //Check if webinar page

            if (empty($webinar_id)) return false;

            $protected_webinar_id = '';
            $is_webinar_id_protected = WebinarignitionManager::is_webinar_id_protected($webinar_id);

            if (!empty($protected_webinar_id)) $webinar_id = $is_webinar_id_protected;

            // Return Option Object:
            $webinar_data = WebinarignitionManager::get_webinar_data($webinar_id);

            if ( !empty($webinar_data) ) return $webinar_data;
        }

        return false;
    }

    public static function get_webinar_data($id) {
        $webinar_data = get_option( 'webinarignition_campaign_' . $id );
        // $hash_to_id = get_option('webinarignition_map_campaign_hash_to_id', []);
        $id_to_hash = get_option('webinarignition_map_campaign_id_to_hash', []);

        if (!empty($id_to_hash[$id])) {
            $webinar_data->hash_id = $id_to_hash[$id];
        }

        return $webinar_data;
    }

    public static function get_webinar_post_id($webinar_id) {
        global $wpdb;
        $table = "{$wpdb->prefix}webinarignition";
        $query = $wpdb->prepare("SELECT postID FROM {$table} W WHERE W.ID=%d", [$webinar_id]);
        $webinar_post_id = $wpdb->get_var($query);
        return absint($webinar_post_id);
    }

    public static function get_webinar_record_by_id($webinar_id) {
        global $wpdb;
        $table = "{$wpdb->prefix}webinarignition";
        $query = $wpdb->prepare("SELECT * FROM {$table} W WHERE W.ID=%d", [$webinar_id]);
        $webinar = $wpdb->get_row($query, ARRAY_A);
        return $webinar;
    }

	/**
     * Get currently set locale
     *
	 * @return string
	 */
    public static function get_current_locale() {
	    $current_locale = determine_locale();

	    if(is_user_logged_in()) {
		    $current_locale = get_user_locale();
	    }

	    return $current_locale;
    }

	/**
	 * Set locale based on webinar
     * @param $webinar_data
	 */
    public static function set_locale($webinar_data) {
	    $text_domain = 'webinarignition';
	    $mopath = WEBINARIGNITION_PATH . DIRECTORY_SEPARATOR . 'languages' . DIRECTORY_SEPARATOR;

	    $current_locale = self::get_current_locale();

	    if ( isset($webinar_data->webinar_lang) && !empty( $webinar_data->webinar_lang ) && $current_locale !== $webinar_data->webinar_lang ) {
	        $switched = switch_to_locale($webinar_data->webinar_lang);
	        if($switched) {
		        $mo_file = $mopath . $text_domain . '-' . $webinar_data->webinar_lang . '.mo';
				load_textdomain( $text_domain, $mo_file );
	        }
	    }
    }

	/**
	 * Restore webinar locale if changed previously
	 * @param $webinar_data
	 */
	public static function restore_locale($webinar_data) {
	    $current_locale = self::get_current_locale();

	    if ( isset($webinar_data->webinar_lang) && !empty( $webinar_data->webinar_lang ) && $current_locale === $webinar_data->webinar_lang ) {
	        restore_previous_locale();
	    }
    }

	/**
     * Pass webinar hash_ID and get numeric ID
     *
	 * @param $id
	 *
	 * @return false|mixed
	 */
    public static function is_webinar_id_protected($id) {
        $hash_to_id = get_option('webinarignition_map_campaign_hash_to_id', []);
        // $id_to_hash = get_option('webinarignition_map_campaign_id_to_hash', []);

        if (!empty($hash_to_id[$id])) {
            return $hash_to_id[$id];
        }

        return false;
    }

    public static function is_webinar_public($webinar_data) {
        $webinar_access = !empty($webinar_data->protected_webinar_id) ? $webinar_data->protected_webinar_id : 'public';

        return $webinar_access === 'public';
    }

    public static function maybe_redirect_to_custom_page($webinar_data, $lid, $page) {
        $custom_id = false;

        if ($page === 'countdown') {
            if ( !empty($webinar_data->custom_countdown_page) && !empty(get_post($webinar_data->custom_countdown_page))) {
                $custom_id = $webinar_data->custom_countdown_page;
            }
        } elseif ($page === 'webinar') {
            if ( !empty($webinar_data->custom_webinar_page) && !empty(get_post($webinar_data->custom_webinar_page))) {
                $custom_id = $webinar_data->custom_webinar_page;
            }
        } elseif ($page === 'closed') {
            if ( !empty($webinar_data->custom_closed_page) && !empty(get_post($webinar_data->custom_closed_page))) {
                $custom_id = $webinar_data->custom_closed_page;
            }
        } elseif ($page === 'replay') {
            if ( !empty($webinar_data->custom_replay_page) && !empty(get_post($webinar_data->custom_replay_page))) {
                $custom_id = $webinar_data->custom_replay_page;
            }
        } elseif ($page === 'thankyou') {
            if ( !empty($webinar_data->custom_thankyou_page) && !empty(get_post($webinar_data->custom_thankyou_page))) {
                $custom_id = $webinar_data->custom_thankyou_page;
            }
        }

        if (!empty($custom_id)) {
            $webinar_url = get_permalink($custom_id);
            if($webinar_url) {

                $webinar_url = add_query_arg(['lid' => $lid], $webinar_url);

	            wp_redirect( $webinar_url );
            }
        }
    }

    public static function clean_webinar_hash() {
        $hash_to_id = get_option('webinarignition_map_campaign_hash_to_id', []);
        $id_to_hash = get_option('webinarignition_map_campaign_id_to_hash', []);

        global $wpdb;
        $getVersion    = "webinarignition";
        $table_db_name = $wpdb->prefix . $getVersion;
        $webinars = $wpdb->get_results("SELECT * FROM {$table_db_name}", ARRAY_A);

        $hash_to_id_new = [];
        $id_to_hash_new = [];

        foreach ($webinars as $webinar) {
            $ID_new = $webinar['ID'];

            if (!empty($id_to_hash[$ID_new])) {
                $hash_new = $id_to_hash[$ID_new];

                $hash_to_id_new[$hash_new] = $ID_new;
                $id_to_hash_new[$ID_new] = $hash_new;
            }
        }

        update_option('webinarignition_map_campaign_hash_to_id', $hash_to_id_new);
        update_option('webinarignition_map_campaign_id_to_hash', $id_to_hash_new);
    }

    public static function get_host_presenters_url($id) {

        $webinar_data = get_option( 'webinarignition_campaign_' . $id );

        if ( $webinar_data && empty($webinar_data->host_presenters_url)) {

            $host_presenters_url = sha1(serialize($webinar_data) . time() . 'host_presenters_url');
            $webinar_data->host_presenters_url = $host_presenters_url;

            update_option('webinarignition_campaign_' . $id, $webinar_data);

            return $webinar_data->host_presenters_url;
        }

        return '';

    }

    public static function get_support_stuff_url($id) {
        $webinar_data = get_option( 'webinarignition_campaign_' . $id );

        if (empty($webinar_data->support_stuff_url)) {
            $support_stuff_url = sha1(serialize($webinar_data) . time() . 'support_stuff_url');
            $webinar_data->support_stuff_url = $support_stuff_url;

            update_option('webinarignition_campaign_' . $id, $webinar_data);
        }

        return $webinar_data->support_stuff_url;
    }

    /**
     * DEPRECATED WILL REMOVE
     *
     * @param $webinar_data
     * @param $lead_id
     * @param $email_body
     * @param string $additional_params
     *
     * @return string|string[]
     */
    public static function replace_email_body_placeholders($webinar_data, $lead_id, $email_body, $additional_params = '', $args = []) {
        return WebinarignitionEmailManager::replace_email_body_placeholders( $webinar_data, $lead_id, $email_body, $additional_params, $args );
    }

    public static function get_webinar_page_template($webinar_data) {
        if (!WebinarignitionPowerups::is_modern_template_enabled($webinar_data)) return 'classic';

        return !empty($webinar_data->webinar_template) ? $webinar_data->webinar_template : 'classic';
    }

    public static function get_webinar_cta_by_position($webinar_data) {
        $webinar_type = $webinar_data->webinar_date == "AUTO" ? 'evergreen' : 'live';

        if ('evergreen' !== $webinar_type) {
            return false;
        }

        $is_time = $webinar_data->auto_action === "time";

        $return_data = [
            'is_time' => $webinar_data->auto_action === "time",
            'outer' => [],
            'overlay' => [],
        ];

        $additional_autoactions = [];

        if ($is_time && WebinarignitionPowerups::is_multiple_cta_enabled($webinar_data)) {
            if (!empty($webinar_data->additional_autoactions)) {
                $additional_autoactions = unserialize($webinar_data->additional_autoactions);
            }
        }

        $cta_position_default = 'outer';

        if (
            !empty($webinar_data->auto_action_time) && (
                !empty($webinar_data->auto_action_copy)
                || (!empty($webinar_data->auto_action_btn_copy) && !empty($webinar_data->auto_action_url))
            )
        ) {
            $webinar_main_auto_action = [
                'is_main' => true,
                'auto_action_time' => $webinar_data->auto_action_time,
                'auto_action_time_end' => '',
                'auto_action_copy' => '',
                'auto_action_btn_copy' => '',
                'auto_action_url' => '',
                'auto_action_title' => __('Click here', 'webinarignition'),
                'replay_order_color' => '#6BBA40',
            ];

            if (!empty($webinar_data->auto_action_time_end)) {
                $webinar_main_auto_action['auto_action_time_end'] = $webinar_data->auto_action_time_end;
            }

            if (!empty($webinar_data->replay_order_color)) {
                $webinar_main_auto_action['replay_order_color'] = $webinar_data->replay_order_color;
            }

            if (!empty($webinar_data->auto_action_copy)) {
                $webinar_main_auto_action['auto_action_copy'] = $webinar_data->auto_action_copy;
            }

            if (!empty($webinar_data->auto_action_max_width)) {
                $webinar_main_auto_action['auto_action_max_width'] = $webinar_data->auto_action_max_width;
            }

            if (!empty($webinar_data->auto_action_btn_copy)) {
                $webinar_main_auto_action['auto_action_title'] = $webinar_data->auto_action_btn_copy;

                if (!empty($webinar_data->auto_action_url)) {
                    $webinar_main_auto_action['auto_action_btn_copy'] = $webinar_data->auto_action_btn_copy;
                    $webinar_main_auto_action['auto_action_url'] = $webinar_data->auto_action_url;
                }
            }

            if (!empty($webinar_data->cta_position) ) {
                $cta_position_default = $webinar_data->cta_position;
            }

            if ($cta_position_default === 'outer') {
                $webinar_main_auto_action['cta_position'] = 'outer';
                $additional_autoactions[0] = $webinar_main_auto_action;
            } else {
                $webinar_main_auto_action['cta_position'] = 'overlay';
                $additional_autoactions[0] = $webinar_main_auto_action;
            }
        }

        ksort($additional_autoactions);

        foreach ($additional_autoactions as $index => $additional_autoaction) {
            $cta_position = $cta_position_default;

            if (!empty($additional_autoaction['cta_position'])) {
                $cta_position = $additional_autoaction['cta_position'];
            }

            $return_data[$cta_position][$index] = $additional_autoaction;
        }

        return $return_data;
    }

    /**
     * @param $app_id
     * @param $data
     * @param string $host_presenters_url
     * @param string $support_stuff_url
     *
     * @return false
     */
    public static function register_support($app_id, $data, $host_presenters_url = '', $support_stuff_url = '') {
        if (empty($host_presenters_url) && empty($support_stuff_url)) return false;

        $webinar_data = get_option( 'webinarignition_campaign_' . $app_id );
        if (empty($webinar_data)) return false;

        if (!empty($host_presenters_url)) {
            $enabled = 'enable_multiple_hosts';
            $count = 'host_member_count';
            $prefix = 'host_member_';
            $meta_prefix = '_wi_host_';
            $role = 'webinarignition_host';
        } else {
            $enabled = 'enable_support';
            $count = 'support_staff_count';
            $prefix = 'member_';
            $meta_prefix = '_wi_support_';
            $role = 'webinarignition_support';
        }

        if (isset($webinar_data->{$enabled}) && ($webinar_data->{$enabled} == 'yes')) {
            $exists = false;

            if (!empty($webinar_data->{$count})) {
                for ( $x = 1; $x <= $webinar_data->{$count}; $x++ ){
                    $email_str       = $prefix . "email_" . $x;

                    if( property_exists($webinar_data, $email_str) && $webinar_data->{$email_str} === $data['email'] ) {
                        $exists = true;
                        break;
                    }
                }
            }

            if (!$exists) {
                $x = $webinar_data->{$count};
                $x++;
                $webinar_data->{$count} = $x;

                foreach ($data as $field => $value) $webinar_data->{$prefix . $field . "_" . $x} = $value;

                update_option('webinarignition_campaign_' . $app_id, $webinar_data);
            }

            $member = get_user_by( 'email',  $data['email']);

            if (empty($member)) {
                $member_email           = $data['email'];
                $member_first_name      = $data['first_name'];
                $member_last_name       = $data['last_name'];

                $password       = wp_generate_password( absint( 15 ), true, false );
                $display_name   = trim( $member_first_name . ' ' . $member_last_name );

                $user_id        = wp_insert_user( [
                    'user_login'    => $member_email,
                    'user_email'    => sanitize_email( $member_email ),
                    'user_pass'     => $password,
                    'display_name'  => $display_name,
                    'first_name'    => $member_first_name,
                    'last_name'     => $member_last_name,
                    'role'          => $role
                ] );
            } else {
                $user_id = $member->ID;
            }

            $_wi_support_token = get_user_meta($user_id, $meta_prefix . 'token', true);
            $_wi_support_status = get_user_meta($user_id, $meta_prefix . 'status', true);

            if (empty($_wi_support_token)) {
                $_wi_support_token = md5( $user_id . time() . uniqid( '', true ) );
                update_user_meta( $user_id, $meta_prefix . 'token', $_wi_support_token );
            }

            if (empty($_wi_support_status)) update_user_meta( $user_id, $meta_prefix . 'status', 'pending' );

            $_app_id_support_token = get_user_meta($user_id, $meta_prefix . 'token_' . $app_id, true);
            $_app_id_support_status = get_user_meta($user_id, $meta_prefix . 'status_' . $app_id, true);

            if (empty($_app_id_support_token)) {
                $_app_id_support_token = md5( $app_id . $user_id . time() . uniqid( '', true ) );
                update_user_meta( $user_id, $meta_prefix . 'token_' . $app_id, $_app_id_support_token );
            }

            if (empty($_app_id_support_status)) update_user_meta( $user_id, $meta_prefix . 'status_' . $app_id, 'pending' );

            return $_wi_support_token;

            if (!empty($host_presenters_url)) {
                return $_app_id_support_token;
            } else {
                return $_wi_support_token;
            }
        } else {
            return false;
        }
    }

    public static function generate_support_token( $user_id, $app_id, $meta_prefix, $status = 'pending' ) {
        $_wi_support_token = get_user_meta($user_id, $meta_prefix . 'token', true);
        $_wi_support_status = get_user_meta($user_id, $meta_prefix . 'status', true);
        $_app_id_support_token = get_user_meta($user_id, $meta_prefix . 'token_' . $app_id, true);
        $_app_id_support_status = get_user_meta($user_id, $meta_prefix . 'status_' . $app_id, true);

        if (empty($_wi_support_token)) {
            $_wi_support_token = md5( $user_id . time() . uniqid( '', true ) );
            update_user_meta( $user_id, $meta_prefix . 'token', $_wi_support_token );
        }

        if (empty($_wi_support_status) || $status !== $_wi_support_status) {
            update_user_meta( $user_id, $meta_prefix . 'status', $status );
        }

        if (empty($_app_id_support_token)) {
            $_app_id_support_token = md5( $app_id . $user_id . time() . uniqid( '', true ) );
            update_user_meta( $user_id, $meta_prefix . 'token_' . $app_id, $_app_id_support_token );
        }

        if (empty($_app_id_support_status) || $status !== $_app_id_support_status) {
            update_user_meta( $user_id, $meta_prefix . 'status_' . $app_id, $status );
        }
    }

    public static function is_support_enabled($webinar_data, $type = 'support') {
        if (!WebinarignitionPowerups::is_multiple_support_enabled($webinar_data)) return false;

        if ( $type === 'support' ) {
            return !empty($webinar_data->enable_support)
                   && 'yes' === $webinar_data->enable_support
                   && !empty($webinar_data->console_q_notifications)
                   && 'yes' === $webinar_data->console_q_notifications;
        } elseif ( $type === 'host' ) {
            return !empty($webinar_data->enable_multiple_hosts)
                    && 'yes' === $webinar_data->enable_multiple_hosts;
        }

        return false;
    }

    public static function extra_user_profile_fields( $user ) {
        return;
        $id = $user->ID;

        $host_token = esc_attr( get_the_author_meta( '_wi_host_token', $user->ID ) );
        $support_token = esc_attr( get_the_author_meta( '_wi_support_token', $user->ID ) );

        if (empty($host_token) && empty($support_token)) {
            return;
        }
        ?>
        <h3><?php _e("Webinarignition Profile", "webinarignition"); ?></h3>

        <table class="form-table">

        </table>
        <?php
    }

    public static function is_auto_webinar( $webinar_data ) {
		return ( isset($webinar_data->webinar_date) && strtolower($webinar_data->webinar_date) === 'auto' ) ;
	}

    public static function is_paid_webinar( $webinar_data ) {
        $paid_status = isset($webinar_data->paid_status) ? strtolower(trim($webinar_data->paid_status)) : null;
        $paid_code   = isset($webinar_data->paid_code) ? trim($webinar_data->paid_code) : null;
        if(isset($webinar_data->paid_status))

		return ( $paid_status === 'paid' && !empty($paid_code) );
	}

    public static function get_paid_webinar_type( $webinar_data ) {
        $paid_type = isset($webinar_data->paid_button_type) ? strtolower(trim($webinar_data->paid_button_type)) : null;

        if(empty($paid_type)) {
	        $paid_type = false;
        }

        return $paid_type;
	}

	public static function get_webinar_page_id($webinar_data, $page_type) {
		$page_id = 0;

		if( $page_type === 'webinar' ) {
			$page_id = isset($webinar_data->custom_webinar_page) ? absint($webinar_data->custom_webinar_page) : 0;
		} else if( $page_type === 'registration' ) {
			$page_id = isset($webinar_data->custom_registration_page) ? absint($webinar_data->custom_registration_page) : 0;
		} else if ($page_type === 'countdown') {
			$page_id = isset($webinar_data->custom_countdown_page) ? absint($webinar_data->custom_countdown_page) : 0;
		} elseif ($page_type === 'closed') {
			$page_id = isset($webinar_data->custom_closed_page) ? absint($webinar_data->custom_closed_page) : 0;
		} elseif ($page_type === 'replay') {
			$page_id = isset($webinar_data->custom_replay_page) ? absint($webinar_data->custom_replay_page) : 0;
		} elseif ($page_type === 'thank_you' || $page_type === 'thankyou') {
			$page_id = isset($webinar_data->custom_thankyou_page) ? absint($webinar_data->custom_thankyou_page) : 0;
		}

		if( empty($page_id) || get_post_type($page_id) === false ) {
			$page_id    = self::get_webinar_post_id($webinar_data->id);
		}

		return $page_id;
	}

	public static function get_permalink($webinar_data, $page_type) {
		$page_id = self::get_webinar_page_id($webinar_data, $page_type);

		return get_the_permalink($page_id);
	}

	public static function get_user_from_wc_order_id() {

        $input_get = filter_input_array( INPUT_GET );

		$user_email = ( isset($input_get['sremail']) && !empty($input_get['sremail']) ) ? trim(sanitize_text_field($input_get['sremail'])) : null;

		$order_id = self::url_has_valid_wc_order_id();
		$user = null;

		if( !empty($order_id) ) { //Consider it as paid webinar redirect
			$order = wc_get_order( $order_id );
            $order_user_id = $order->get_user_id();

            if( $order->has_shipping_address() ) {
                $user_first_name = $order->get_shipping_first_name();
                $user_last_name  = $order->get_shipping_last_name();
            } else {
                $user_first_name = $order->get_billing_first_name();
                $user_last_name  = $order->get_billing_last_name();
            }

            $user_full_name  = "{$user_first_name} {$user_last_name}";
            if ( empty( $user_email ) ) {
                $user_email = $order->get_billing_email();
            }

            $user = json_decode(json_encode([
                'ID' => $order_user_id,
                'display_name' => "{$user_full_name}",
                'first_name' => "{$user_first_name}",
                'last_name'  => "{$user_last_name}",
                'user_email' => "{$user_email}",
            ]));

		}

		return $user;
	}

	public static function url_has_valid_paid_code($webinar_data) {
		$webinar_paid_code = trim($webinar_data->paid_code);

        return ( !empty( $webinar_paid_code ) && isset($_GET[$webinar_paid_code]) );
	}

	public static function url_is_confirmed_set() {
		return isset($_GET['confirmed']);
	}

	public static function url_has_valid_lead_id() {
		$input_get = filter_input_array( INPUT_GET );

		if( isset($input_get['lid']) ) {
			$lead_id = trim($input_get['lid']);
			if( !empty($lead_id) ) {
			    return $lead_id;
            }
        }

		return false;
	}

	/**
     * Check if page/post is in preview mode for any third-party page builder
     *
	 * @return bool
	 */
	private static function is_builder_preview() {
        //Elementor
		if ( class_exists('\Elementor\Plugin') && \Elementor\Plugin::$instance->preview->is_preview_mode($post->ID) && $has_editor_access ) {
			return true;
		}

		//OptimizePress
		if( class_exists('OPBuilder\Providers\BuilderBootstrap') && $has_editor_access ) { //Check if OptimizePress3 is active and user has editor access

			if( class_exists('OPBuilder\Providers\BuilderBootstrap') && $has_editor_access ) { //Check if OptimizePress3 is active and user has editor access
				if( function_exists('op3_is_admin') && function_exists('is_op3_page') ) {
					if ( is_op3_page( $post->ID ) && (op3_is_admin() || is_preview()) ) {
						return true;
					}
				}
			}
		}

		//Fusion/Avada
		$is_avada_builder_preview = ( function_exists( 'fusion_is_preview_frame' ) && fusion_is_preview_frame() ) || ( function_exists( 'fusion_is_builder_frame' ) && fusion_is_builder_frame() );
		if( $is_avada_builder_preview ) {
			return true;
		}

		return false;
	}

	public static function url_is_preview_page() {
		$input_get = filter_input_array( INPUT_GET );

		//Check if current user has editor access for this particular post/page
		$has_editor_access = current_user_can( 'edit_published_pages' );

		return (
			    $has_editor_access &&
		        (
		                is_preview() ||
		                self::is_builder_preview() ||
                        isset($input_get['preview_auto_thankyou']) ||
                        isset($input_get['preview-webinar']) ||
                        isset($input_get['preview-replay']) ||
                        isset($input_get['preview-countdown']) ||
                        ( isset($input_get['lid']) && $input_get['lid'] === '[lead_id]' )
                )
        );
	}

	public static function url_has_valid_wc_order_id() {

        if ( isset( $_GET['order'] ) ) {
			$order_id = absint( $_GET['order'] );
			if ( !empty( $order_id ) && class_exists( 'WooCommerce' ) ) {
				$order = wc_get_order( $order_id );

				if ( !empty( $order ) ) {
					return $order_id;
				}
			}
		} else if ( isset( $_GET['order_id'] ) ) {
			$order_id = absint( $_GET['order_id'] );
			if ( !empty( $order_id ) && class_exists( 'WooCommerce' ) ) {
				$order = wc_get_order( $order_id );

				if ( !empty( $order ) ) {
					return $order_id;
				}
			}
		}

        return false;
	}

	public static function url_is_calendar_page() {
        global $post;

        if($post) {
            $input_get = filter_input_array( INPUT_GET );
	        return (
                isset( $input_get['googlecalendarA'] ) ||
                isset( $input_get['icsA'] )  ||
                isset( $input_get['googlecalendar'] )  ||
                isset( $input_get['ics'] )
            );
        }

		return false;
	}

	/**
     * Return auto redirect URL only when enabled and has valid URL, false otherwise
     *
	 * @param $webinar_data
	 */
	public static function get_auto_redirect_url($webinar_data) {

		if(
            isset($webinar_data->auto_redirect) &&
            $webinar_data->auto_redirect === 'redirect' &&
            isset($webinar_data->auto_redirect_url) &&
            wp_http_validate_url($webinar_data->auto_redirect_url, FILTER_VALIDATE_URL)
        ) {
			return $webinar_data->auto_redirect_url;
		}

		return false;
	}
}
